@@ -14,7 +14,7 @@ pascal_per_millibar = 100
 seconds_in_hour = 3600
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.4.3'
+jaws_version = '0.4.4'
 
 ###############################################################################
 
@@ -36,6 +36,8 @@ def load_dataframe(name, input_file, header_rows, **kwargs):
 		skip_blank_lines=True,
 		header=None,
 		names=columns,
+		sep=r'\t|\s+|\,', 
+		engine='python',
 		**kwargs)
 
 
